bayespy.inference.vmp.nodes.gaussian_markov_chain.SwitchingGaussianMarkovChainDistribution.compute_weights_to_parent
====================================================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian_markov_chain

.. automethod:: SwitchingGaussianMarkovChainDistribution.compute_weights_to_parent